import { MultiModalEmbedding } from "@llamaindex/core/embeddings";
import type { ImageType } from "../Node.js";
type TaskType = "retrieval.passage" | "retrieval.query" | "separation" | "classification" | "text-matching";
type EncodingType = "float" | "binary" | "ubinary";
export type JinaEmbeddingRequest = {
    input: Array<{
        text: string;
    } | {
        url: string;
    } | {
        bytes: string;
    }>;
    model?: string;
    encoding_type?: EncodingType;
    task?: TaskType;
    dimensions?: number;
    late_chunking?: boolean;
};
export type JinaEmbeddingResponse = {
    model: string;
    object: string;
    usage: {
        total_tokens: number;
        prompt_tokens: number;
    };
    data: Array<{
        object: string;
        index: number;
        embedding: number[];
    }>;
};
export declare class JinaAIEmbedding extends MultiModalEmbedding {
    apiKey: string;
    model: string;
    baseURL: string;
    task?: TaskType | undefined;
    encodingType?: EncodingType | undefined;
    dimensions?: number | undefined;
    late_chunking?: boolean | undefined;
    getTextEmbedding(text: string): Promise<number[]>;
    getImageEmbedding(image: ImageType): Promise<number[]>;
    getTextEmbeddings: (texts: string[]) => Promise<Array<number[]>>;
    getImageEmbeddings(images: ImageType[]): Promise<number[][]>;
    constructor(init?: Partial<JinaAIEmbedding>);
    private getImageInput;
    private getJinaEmbedding;
}
export {};
